@@ -14,15 +14,15 @@ from mtcli.conf import (
     POSITION_CANCELED_ERROR,
     POSITION_CANCELED_SUCCESS,
 )
-from mtcli import __version__
+import mtcli
 
 
 @click.group(invoke_without_command=True)
-@click.option("--version", is_flag=True, help="Exibe a versao do mtcli")
+@click.option("--version", is_flag=True, help="Exibe a versao")
 def cli(version):
     """Converte graficos do MetaTrader 5 para texto."""
     if version:
-        click.echo("mtcli v%s" % __version__)
+        click.echo("mtcli v%s" % mtcli.__version__)
 
 
 @click.command()
